@@ -18,6 +18,22 @@ async def get_config(server_url, model_name, verbose=False):
         return response
 
 
+def _encode_input(data):
+    # automatically encode string and dict into np.bytes_
+    if isinstance(data, str):
+        bytes_data = str.encode(data, "utf-8")
+        in_data = np.array([bytes_data], dtype=np.object_)
+    elif isinstance(data, dict):
+        # encode the dictionary as as np.object_
+        bytes_data = str.encode(json.dumps(data), "utf-8")
+        in_data = np.array([bytes_data], dtype=np.object_)
+    elif isinstance(data, (tuple, list)):
+        in_data = np.stack(list(map(_encode_input, data)), axis=0)
+    else:
+        in_data = data
+    return in_data
+
+
 async def execute_model(
     inputs,
     server_url=None,
@@ -29,6 +45,7 @@ async def execute_model(
     compression_algorithm="deflate",
     decode_bytes=False,
     verbose=False,
+    **kwargs,
 ):
     """
     Function for execute the model by passing a list of input tensors
@@ -52,16 +69,11 @@ async def execute_model(
         inputc[i]["data_type"].lstrip("TYPE_").replace("STRING", "BYTES")
         for i in range(len(inputc))
     ]
-
+    if isinstance(inputs, tuple):
+        inputs = list(inputs)
+    assert isinstance(inputs, list), "Inputs must be a list or tuple"
     for i in range(len(inputs)):
-        # automatically encode string and dict into np.bytes_
-        if isinstance(inputs[i], str):
-            bytes_data = str.encode(inputs[i], "utf-8")
-            inputs[i] = np.array([bytes_data], dtype=np.object_)
-        if isinstance(inputs[i], dict):
-            # encode the dictionary as as np.object_
-            bytes_data = str.encode(json.dumps(inputs[i]), "utf-8")
-            inputs[i] = np.array([bytes_data], dtype=np.object_)
+        inputs[i] = _encode_input(inputs[i])
 
         if inputs[i].dtype != triton_to_np_dtype(input_types[i]):
             if not (
@@ -102,6 +114,7 @@ async def execute_model(
             outputs=outputs,
             request_compression_algorithm=compression_algorithm,
             response_compression_algorithm=compression_algorithm,
+            **kwargs,
         )
 
         info = response.get_response()
@@ -124,6 +137,26 @@ async def execute_model(
         return results
 
 
+_config_cache = {}
+
+
+async def execute(
+    inputs, server_url=None, model_name=None, cache_config=True, **kwargs
+):
+    """
+    Function for execute the model by passing a list of input tensors and using cached config
+    """
+    if cache_config:
+        if (server_url, model_name) not in _config_cache:
+            config = await get_config(server_url, model_name)
+            _config_cache[(server_url, model_name)] = config
+        else:
+            config = _config_cache[(server_url, model_name)]
+    else:
+        config = await get_config(server_url, model_name)
+    return await execute_model(inputs, config=config, **kwargs)
+
+
 # read version information from file
 VERSION_INFO = json.loads(
     (Path(__file__).parent / "VERSION").read_text(encoding="utf-8").strip()
